pydevDAG manual
===============

Contents:

.. toctree::
   :maxdepth: 2

   intro
   architecture
   scripts

   pydevDAG/modules
   tests/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

